# peyecoder
Software for coding eye movements in looking-while-listening tasks.

Running
--
To run peyecoder from the project directory:

```
python run-peyecoder.py
```


Dependencies
--
- **PySide2**: Qt for Python
- **opencv-python**: Computer vision library used to read videos   
- **Pillow**: image manipulation library
- **timecode**: library for SMTPE timecode computations
- **PyAudio**: library used to playback audio
- **sortedcontainers**: data structures which maintain sort order
- **python-dateutil**: date utilities

additionally, **ffmpeg** should be installed and in the path. 


